==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_eo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="eo" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Neniu serĉrezulton</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Ĉu vi vere volas malinstali %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmi</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Forigu de labortablo</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Forigu de doko</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Malinstali</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation>Ludo</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofico</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation>Sistemo</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Ĉu vi vere volas malinstali %1 ?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Ĉiuj dependaĵoj estos forigitaj kune</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmi</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputilo</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Elŝutoj</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloki</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartigi</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Elŝalti</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Komputilo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Elŝalti</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloki</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartigi</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Elŝutoj</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputilo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Elŝutoj</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Mana</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Elŝalti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Serĉi</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Ĉu vi vere volas malinstali %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmi</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_eo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="eo" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Neniu serĉrezulton</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofico</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation>Sistemo</translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmi</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Forigu de labortablo</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Forigu de doko</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Malinstali</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation>Ludo</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofico</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation>Sistemo</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputilo</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Elŝutoj</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloki</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartigi</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Elŝalti</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Komputilo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Elŝalti</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloki</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartigi</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Elŝutoj</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputilo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziko</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Elŝutoj</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Mana</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation>Ŝalto</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Serĉi</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmi</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
